@@ -14,6 +14,7 @@
   OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
   SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """
+import six
 from cfnlint import CloudFormationLintRule
 from cfnlint import RuleMatch
 
@@ -47,20 +48,24 @@ class AllowedValue(CloudFormationLintRule):
                 param = cfn.template.get('Parameters').get(value, {})
                 parameter_values = param.get('AllowedValues')
                 default_value = param.get('Default')
-
-                # Check Allowed Values
-                if parameter_values:
-                    for index, allowed_value in enumerate(parameter_values):
-                        if allowed_value not in allowed_value_specs:
-                            param_path = ['Parameters', value, 'AllowedValues', index]
-                            message = 'You must specify a valid allowed value for {0} ({1}).\nValid values are {2}'
-                            matches.append(RuleMatch(param_path, message.format(value, allowed_value, allowed_value_specs)))
-                elif default_value:
-                    # Check Default, only if no allowed Values are specified in the parameter (that's covered by E2015)
-                    if default_value not in allowed_value_specs:
-                        param_path = ['Parameters', value, 'Default']
-                        message = 'You must specify a valid Default value for {0} ({1}).\nValid values are {2}'
-                        matches.append(RuleMatch(param_path, message.format(value, default_value, allowed_value_specs)))
+                parameter_type = param.get('Type')
+                if isinstance(parameter_type, six.string_types):
+                    if ((not parameter_type.startswith('List<')) and
+                            (not parameter_type.startswith('AWS::SSM::Parameter::Value<')) and
+                            parameter_type not in ['CommaDelimitedList']):
+                        # Check Allowed Values
+                        if parameter_values:
+                            for index, allowed_value in enumerate(parameter_values):
+                                if allowed_value not in allowed_value_specs:
+                                    param_path = ['Parameters', value, 'AllowedValues', index]
+                                    message = 'You must specify a valid allowed value for {0} ({1}).\nValid values are {2}'
+                                    matches.append(RuleMatch(param_path, message.format(value, allowed_value, allowed_value_specs)))
+                        elif default_value:
+                            # Check Default, only if no allowed Values are specified in the parameter (that's covered by E2015)
+                            if default_value not in allowed_value_specs:
+                                param_path = ['Parameters', value, 'Default']
+                                message = 'You must specify a valid Default value for {0} ({1}).\nValid values are {2}'
+                                matches.append(RuleMatch(param_path, message.format(value, default_value, allowed_value_specs)))
 
         return matches
 
